==> clean_android_design-0.0.4.tar.gz: lib/src/utils/item_section_widget.dart <==
import 'package:clean_android_design/src/style/clean_android_design_style.dart';
import 'package:flutter/material.dart';

class ItemSectionWidget extends StatelessWidget {
  final Widget title;
  final List<Widget> children;

  final IndexedWidgetBuilder itemBuilder;
  final int itemCount;

  const ItemSectionWidget({
    Key key,
    this.title,
    this.children,
  })  : itemBuilder = null,
        itemCount = null,
        super(key: key);

  const ItemSectionWidget.builder({
    Key key,
    this.title,
    @required this.itemBuilder,
    @required this.itemCount,
  })  : children = null,
        super(key: key);

  @override
  Widget build(BuildContext context) {
    var columnChildren = List<Widget>();
    if (children != null) {
      var filteredChildren = children
          .where((item) => !(item is Container && item.child == null))
          .toList();

      filteredChildren.asMap().forEach((index, item) {
        if (item is IListItem)
          columnChildren.add(item.copyWithPosition(
              isFirst: index == 0,
              isLast: index == filteredChildren.length - 1));
        else
          columnChildren.add(item);
      });
    }

    return Column(
      mainAxisSize: MainAxisSize.min,
      crossAxisAlignment: CrossAxisAlignment.start,
      children: <Widget>[
        title != null
            ? Padding(
                padding:
                    const EdgeInsets.symmetric(horizontal: 25, vertical: 5),
                child: DefaultTextStyle(
                  child: title,
                  style: TextStyles.textStyleSize(14)
                      .copyWith(fontWeight: FontWeight.w600),
                ),
              )
            : Container(),
        Container(
          decoration: BoxDecoration(
              borderRadius: BorderRadius.circular(30),
              border: Border.all(
                  color: CleanAndroidDesignDefaultColors.defaultColorLight,
                  width: 1),
              color: Colors.white),
          child: itemBuilder == null
              ? Column(
                  children: columnChildren,
                )
              : ListView.builder(
                  shrinkWrap: true,
                  physics: ScrollPhysics(),
                  itemCount: itemCount,
                  itemBuilder: (context, index) {
                    var widget = itemBuilder(context, index);
                    if (widget is IListItem)
                      return widget.copyWithPosition(
                          isFirst: index == 0, isLast: index == itemCount - 1);
                    else
                      return widget;
                  },
                ),
        )
      ],
    );
  }
}

abstract class IListItem extends Widget {
  // ignore: missing_return
  IListItem copyWithPosition({bool isFirst, bool isLast}) {}

  @override
  // ignore: missing_return
  Element createElement() {}
}

==> clean_android_design-0.0.14.tar.gz: lib/src/utils/item_section_widget.dart <==
import 'package:clean_android_design/src/style/clean_android_design_style.dart';
import 'package:flutter/material.dart';

class ItemSectionWidget extends StatelessWidget {
  final Widget title;
  final List<Widget> children;

  final IndexedWidgetBuilder itemBuilder;
  final int itemCount;

  const ItemSectionWidget({
    Key key,
    this.title,
    this.children,
  })  : itemBuilder = null,
        itemCount = null,
        super(key: key);

  const ItemSectionWidget.builder({
    Key key,
    this.title,
    @required this.itemBuilder,
    @required this.itemCount,
  })  : children = null,
        super(key: key);

  @override
  Widget build(BuildContext context) {
    var columnChildren = <Widget>[];
    if (children != null) {
      var filteredChildren = children
          .where((item) => !(item is Container && item.child == null))
          .toList();

      filteredChildren.asMap().forEach((index, item) {
        if (item is IListItem)
          columnChildren.add(item.copyWithPosition(
              isFirst: index == 0,
              isLast: index == filteredChildren.length - 1));
        else
          columnChildren.add(item);
      });
    }

    return Column(
      mainAxisSize: MainAxisSize.min,
      crossAxisAlignment: CrossAxisAlignment.start,
      children: <Widget>[
        title != null
            ? Padding(
                padding:
                    const EdgeInsets.symmetric(horizontal: 25, vertical: 5),
                child: DefaultTextStyle(
                  child: title,
                  style: TextStyles.textStyleSize(14)
                      .copyWith(fontWeight: FontWeight.w600),
                ),
              )
            : Container(),
        Container(
          decoration: BoxDecoration(
              borderRadius: BorderRadius.circular(30),
              border: Border.all(
                  color: CleanAndroidDesignDefaultColors.defaultColorLight,
                  width: 1),
              color: Colors.white),
          child: itemBuilder == null
              ? Column(
                  children: columnChildren,
                )
              : ListView.builder(
                  shrinkWrap: true,
                  physics: ScrollPhysics(),
                  itemCount: itemCount,
                  itemBuilder: (context, index) {
                    var widget = itemBuilder(context, index);
                    if (widget is IListItem)
                      return widget.copyWithPosition(
                          isFirst: index == 0, isLast: index == itemCount - 1);
                    else
                      return widget;
                  },
                ),
        )
      ],
    );
  }
}

abstract class IListItem extends Widget {
  // ignore: missing_return
  IListItem copyWithPosition({bool isFirst, bool isLast}) {}

  @override
  // ignore: missing_return
  Element createElement() {}
}
